==> AffyCompatible_1.0.1.zip: AffyCompatible/R-ex/NetAffxResource-class.R <==
### Name: NetAffxResource-class
### Title: Manage NetAffx annotations
### Aliases: NetAffxResource-class
###   [[,NetAffxResource,numeric,missing-method
###   [[,NetAffxResource,numeric,character-method
###   [[,NetAffxResource,numeric,numeric-method
###   [[,NetAffxResource,character,missing-method
###   [[,NetAffxResource,character,numeric-method
###   [[,NetAffxResource,character,character-method
###   affxLicence,NetAffxResource-method affxUrl,NetAffxResource-method
###   annotationsFile,NetAffxResource-method
###   directory,NetAffxResource-method names,NetAffxResource-method
###   password,NetAffxResource-method readAnnotation
###   readAnnotation,NetAffxResource,character,character-method
###   readAnnotation,NetAffxResource,character,numeric-method
###   readAnnotation,NetAffxResource,missing,AffxAnnotation-method
###   readAnnotation,NetAffxResource,numeric,character-method
###   readAnnotation,NetAffxResource,numeric,numeric-method
###   show,NetAffxResource-method user,NetAffxResource-method
### Keywords: classes

### ** Examples

if (exists("username") && exists("password") && exists("affxLicence")) {
    rsrc <- NetAffxResource(user=username, password=password,
        affxLicence=affxLicence)
    head(names(rsrc))
    affxDescription(rsrc[["Bovine"]])
    ## paradigm to display all elements of 'annotation'
    sapply(affxAnnotation(rsrc[["Bovine"]]), force)
    ## obtain and read a single annotation
    anno <- rsrc[["Porcine", "BLASTP annotations, CSV Format"]]
    df <- readAnnotation(rsrc, annotation=anno)
}

==> AffyCompatible_1.4.0.zip: AffyCompatible/R-ex/NetAffxResource-class.R <==
### Name: NetAffxResource-class
### Title: Manage NetAffx annotations
### Aliases: NetAffxResource-class
###   [[,NetAffxResource,numeric,missing-method
###   [[,NetAffxResource,numeric,character-method
###   [[,NetAffxResource,numeric,numeric-method
###   [[,NetAffxResource,character,missing-method
###   [[,NetAffxResource,character,numeric-method
###   [[,NetAffxResource,character,character-method
###   affxLicence,NetAffxResource-method affxUrl,NetAffxResource-method
###   annotationsFile,NetAffxResource-method
###   directory,NetAffxResource-method names,NetAffxResource-method
###   password,NetAffxResource-method readAnnotation
###   readAnnotation,NetAffxResource,character,character-method
###   readAnnotation,NetAffxResource,character,numeric-method
###   readAnnotation,NetAffxResource,missing,AffxAnnotation-method
###   readAnnotation,NetAffxResource,numeric,character-method
###   readAnnotation,NetAffxResource,numeric,numeric-method
###   show,NetAffxResource-method user,NetAffxResource-method
### Keywords: classes

### ** Examples

## Don't show: 
    password="jnkdna"
## End Don't show
## password must be obtained by the user
rsrc <- NetAffxResource(user="mtmorgan@fhcrc.org", password=password)
head(names(rsrc))
affxDescription(rsrc[["Bovine"]])
## paradigm to display all elements of 'annotation'
sapply(affxAnnotation(rsrc[["Bovine"]]), force)
## obtain and read a single annotation
anno <- rsrc[["Porcine", "BLASTP annotations, CSV Format"]]
df <- readAnnotation(rsrc, annotation=anno)
